# tomtombrumbrum
**The package is still under construction.**

This library aims to simplify the usage of the TomTom API.

**To use their API you need an API key.** 

For more information, go to the [official website](https://developer.tomtom.com/).

This project and its authors are not affiliated in any way to TomTom. For more information, see DISCLAIMER.txt.

Author: Gabriele3vi
# Usage
## Matrix routing v2 API
...